<?php
namespace PTPay\MeoWallet\Block\Adminhtml;

use Magento\Backend\Block\Template;
use Magento\Backend\Block\Widget\Tab\TabInterface;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\Encryption\EncryptorInterface;
use Magento\Framework\Registry;
use \Magento\Integration\Controller\Adminhtml\Integration as IntegrationController;
use \PTPay\MeoWallet\Model\MeoWallet;
use PTPay\MeoWallet\Model\MeoWalletCheckoutFactory;
use PTPay\MeoWallet\SDK\Api as MeoWalletApi;
use Magento\Framework\Data\Collection;
use Magento\Framework\Serialize\SerializerInterface;

/**
 * Block responsible for the multibanco page on the backoffice
 *
 * @package PTPay\MeoWallet\Block\Adminhtml
 */
class Multibanco extends Template implements TabInterface
{

    /**
     * @var MeoWallet
     */
    private $meoWallet;
    /**
     * @var Registry
     */
    private $registry;
    /**
     * @var EncryptorInterface
     */
    private $enc;

    /**
     * @var MeoWalletCheckoutFactory
     */
    private $meoWalletCheckoutFactory;

    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;

    /**
     * Multibanco constructor.
     *
     * @param MeoWallet        $meoWallet
     * @param Registry         $registry
     * @param Template\Context $context
     * @param array            $data
     */
    public function __construct(
        MeoWallet $meoWallet,
        Registry $registry,
        Template\Context $context,
        EncryptorInterface $encryptor,
        MeoWalletCheckoutFactory $meoWalletCheckoutFactory,
        ScopeConfigInterface $scopeConfig,
        array $data
    ) {
        parent::__construct($context, $data);
        $this->meoWallet = $meoWallet;
        $this->registry = $registry;
        $this->enc = $encryptor;
        $this->meoWalletCheckoutFactory = $meoWalletCheckoutFactory;
        $this->scopeConfig = $scopeConfig;
    }


    /**
     * Get tab title
     *
     * @return string
     * @codeCoverageIgnore
     */
    public function getTabTitle()
    {
        return $this->getTabLabel();
    }

    /**
     * Get tab label
     *
     * @return \Magento\Framework\Phrase
     * @codeCoverageIgnore
     */
    public function getTabLabel()
    {
        return __('MeoWallet - Multibanco');
    }

    /**
     * Whether tab is available
     *
     * @return bool
     */
    public function canShowTab()
    {
        return true;
    }

    /**
     * Whether tab is visible
     *
     * @return bool
     * @codeCoverageIgnore
     */
    public function isHidden()
    {
        return false;
    }

    /**
     * Get the multibanco references for the current order
     *
     * @return array
     */
    public function getMultibancoReferences()
    {

        $mbData = $this->meoWallet->multibanco()->getMBReferencesByOrderId($this->getOrder()->getEntityId());

        return $mbData;
    }
    public function getCheckoutData(){

        /** @var AbstractCollection $checkoutCollection */
        $checkoutCollection = $this->meoWalletCheckoutFactory->create()->getCollection();
        $checkouts = $checkoutCollection->addFilter('sales_order_id', $this->getOrder()->getEntityId())->addOrder('created_at',
            Collection::SORT_ORDER_DESC)->getData();
        $checkout_id = false;

        foreach ($checkouts as $checkout){
            $checkout_id = $checkout['meowallet_checkout_id'];
        }
        if (!$checkout_id) return [];

        $checkout_cache = unserialize($this->_cache->load('cka'.$checkout_id));

        if ($checkout_cache) {
            $checkout_data = $checkout_cache;

        }else {
            $environment = $this->scopeConfig->getValue('payment/wallet/environment',
                \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
            $apikey = $this->enc->decrypt($this->scopeConfig->getValue('payment/wallet/sandbox_apikey',
                \Magento\Store\Model\ScopeInterface::SCOPE_STORE));

            $meoWalletApi = new MeoWalletApi($apikey, $environment);
            $checkoutApi = new \PTPay\MeoWallet\SDK\Resources\Checkout($meoWalletApi);
            $checkout_data = $checkoutApi->get($checkout_id);
            $this->_cache->save('cka'.$checkout_id,serialize($checkout_data),['checkout'],600);

        }

        if ($checkout_data['payment']['status'] != "NEW") {
            $checkout_data['payment']['method_str'] = "METHOD_USED_".$checkout_data['payment']['method'];
            return [$checkout_data];
        }
        return [];


    }

    /**
     * Retrieve current order model instance
     *
     * @return \Magento\Sales\Model\Order
     */
    public function getOrder()
    {
        return $this->registry->registry('current_order');
    }

    /**
     * Submit URL getter
     *
     * @return string
     */
    public function getSubmitUrl()
    {
        return $this->getUrl('meowallet/*/createMultibancoReference', ['id' => $this->getOrder()->getId()]);
    }

    /**
     * Class constructor
     *
     * @return void
     */
    protected function _construct()
    {
        parent::_construct();

    }

}
