<?php
namespace PTPay\MeoWallet\Block;

use Klarna\Core\Model\Order;
use Magento\Checkout\Model\Session as CheckoutSession;
use Magento\Framework\Api\SearchCriteriaBuilder;
use Magento\Framework\View\Element\Template;
use Magento\Framework\View\Element\Template\Context;
use Magento\Sales\Model\OrderFactory;
use PTPay\MeoWallet\Helper\Multibanco;
use PTPay\MeoWallet\Model\MeoWallet;

/**
 * Shows the multibanco reference to the user after checkout
 *
 * @package PTPay\MeoWallet\Block
 */
class ShowMbwayPayment extends Template
{
    /** @var bool|array */
    protected $mbwayData;

    /** @var MeoWallet $meoWallet */
    private $meoWallet;


    /** @var OrderRepository $orderRepository */
    private $orderRepository;


    /**
     * @var SearchCriteriaBuilder
     */
    private $searchCriteriaBuilder;

    public function __construct(
        Context $context,
        MeoWallet $meoWallet,
        CheckoutSession $session,
        \Magento\Sales\Model\OrderRepository $orderRepository,
        \Magento\Framework\Api\SearchCriteriaBuilder $searchCriteriaBuilder,
        array $data = []
    ) {
        parent::__construct($context, $data);
        $this->meoWallet = $meoWallet;
        $this->orderRepository = $orderRepository;
        $this->mbwayData = $session->getMbWayResponse();
        $this->searchCriteriaBuilder = $searchCriteriaBuilder;
    }

    /**
     * @return array|bool
     */
    public function getMbwayData() {
        return $this->mbwayData;
    }

    //DONE- item 6 - offset of undefined
    public function getOrderStatus() {
        $mbwayData = $this->getMbwayData();
        
        if (isset($mbwayData['ext_invoiceid'])) {
            $order = $this->loadOrder($mbwayData['ext_invoiceid']);
            return $order->getStatus();
        } else {
            return 'Ext_invoiceid not found on Mbway data';
        }
        // $order = $this->loadOrder($this->getMbwayData()['ext_invoiceid']);
        // return $order->getStatus();
    }

    /**
     * @param $order_id
     * @return \Magento\Sales\Model\Order
     * @throws \Exception
     */
    private function loadOrder($order_id) {

        $searchCriteria = $this->searchCriteriaBuilder
            ->addFilter('increment_id', intval($order_id), 'eq')->create();
        $orderList = $this->orderRepository->getList($searchCriteria)->getItems();

        $order = current($orderList);
        if ($order) {
            return $order;
        }
        throw new \Exception("Order ".$order_id." not found");

    }
}
