<?php
namespace PTPay\MeoWallet\Block;

use Magento\Framework\View\Element\Template;
use Magento\Framework\View\Element\Template\Context;
use PTPay\MeoWallet\Helper\Multibanco;
use PTPay\MeoWallet\Model\MeoWallet;

/**
 * Shows the multibanco reference to the user after checkout
 *
 * @package PTPay\MeoWallet\Block
 */
class ShowMultibancoReference extends Template
{
    /** @var bool|\Magento\Framework\DataObject $mbData */
    protected $mbData;

    /** @var MeoWallet $meoWallet */
    private $meoWallet;

    public function __construct(
        Context $context,
        MeoWallet $meoWallet, 
        array $data = []
    ) {
        parent::__construct($context, $data);
        $this->meoWallet = $meoWallet;

        $operationId = $this->_request->getParam('id');
        $this->mbData = $this->meoWallet->multibanco()->getMBReferencesByOperationId($operationId);
    }

    /**
     * Get the mb entity
     *
     * @return string
     */
    public function getEntity()
    {
        return $this->mbData->getData('entity');
    }


    /**
     * Get the mb reference
     *
     * @return string
     */
    public function getReference()
    {
        $ref = $this->mbData->getData('reference');
        return Multibanco::formatReference($ref);
    }

    /**
     * Get the mb amount with currency information
     *
     * @return string
     */
    public function getAmount()
    {
        $amount = $this->mbData->getData('amount');
        $currency = $this->mbData->getData('currency');

        return Multibanco::formatAmount($amount, $currency);
    }

    /**
     * Get the reference expiration date
     *
     * @return string
     */
    public function getExpireDate()
    {
        $expiresAt = $this->mbData->getData('expires_at');
        return Multibanco::formatExpireDate($expiresAt);
    }

}