<?php
namespace PTPay\MeoWallet\Controller\Adminhtml\Order;

use Magento\Sales\Api\Data\OrderInterface;
use Magento\Sales\Model\Order;
use PTPay\MeoWallet\Helper\Multibanco;
use PTPay\MeoWallet\Helper\OrderManagement;
use PTPay\MeoWallet\Model\MeoWallet;

/**
 * Class CreateMultibancoReference
 * Responsible for the multibanco reference creation inside the backoffice
 *
 * @package PTPay\MeoWallet\Controller\Adminhtml\Order
 */
class CreateMultibancoReference extends \Magento\Sales\Controller\Adminhtml\Order
{
    /**
     * Authorization level of a basic admin session
     *
     * @see _isAllowed()
     */
    const ADMIN_RESOURCE = 'Magento_Sales::comment';

    /**
     * Create a new reference and send it to the backoffice
     *
     * @return \Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {
        $order = $this->_initOrder();

        $result = $this->resultJsonFactory->create();

        /** @var MeoWallet $meoWallet */
        $meoWallet = $this->_objectManager->create(MeoWallet::class);

        /** @var OrderManagement $orderManagementHelper */
        $orderManagementHelper = $this->_objectManager->create(OrderManagement::class);


        // Check if the multibanco reference can be created
        if (!$this->canCreateMB($order)) {
            $data = [
                'error'   => true,
                'message' => __('Multibanco reference could not be created with the current order state')
            ];

            return $result->setData($data);
        }


        /**
         * Create the multibanco reference
         */
        $mbReference = $meoWallet->multibanco()->createMBReference($order);
        if (!$mbReference) {
            $data = [
                'error'   => true,
                'message' => __('Multibanco reference could not be created')
            ];

            return $result->setData($data);
        }

        $data = [
            'mbData' => [
                'createdAt'   => $mbReference->getData('created_at'),
                'operationId' => $mbReference->getData('meowallet_operation_id'),
                'entity'      => $mbReference->getData('entity'),
                'reference'   => Multibanco::formatReference($mbReference->getData('reference')),
                'amount'      => Multibanco::formatAmount($mbReference->getData('amount'),
                    $mbReference->getData('currency')),
                'expires'     => Multibanco::formatExpireDate($mbReference->getData('expires_at')),
                'status'      => $mbReference->getData('status'),
            ]
        ];


        $orderManagementHelper->addMBToHistory($order, $mbReference, $data['mbData']);
        return $result->setData($data)->setHttpResponseCode(200);
    }

    /**
     * Check if a new multibanco reference can be created for the given order
     *
     * @param OrderInterface $order
     *
     * @return bool
     */
    private function canCreateMB($order)
    {
        return in_array($order->getState(), [
            Order::STATE_PENDING_PAYMENT
        ]);
    }
}
