<?php
namespace PTPay\MeoWallet\Controller\Payment;

use Magento\Framework\App\Action\Action;
use Magento\Framework\App\Action\Context;
use Magento\Framework\App\ResponseInterface;
use Magento\Framework\App\RequestInterface;
use Magento\Framework\Controller\ResultFactory;
use Magento\Framework\Exception\LocalizedException;
use PTPay\MeoWallet\Logger\MeoWalletLogger;
use PTPay\MeoWallet\Model\MeoWallet;
use Magento\Framework\App\Request\InvalidRequestException;

/**
 * Class Callback Handles meowallet callbacks
 *
 * @package PTPay\MeoWallet\Controller\Payment
 */
class Callback extends Action implements \Magento\Framework\App\CsrfAwareActionInterface
{
    /**
     * @var Context
     */
    private $context;
    /**
     * @var MeoWallet
     */
    private $meoWallet;
    /**
     * @var MeoWalletLogger
     */
    private $logger;

    /**
     * Callback constructor.
     *
     * @param Context         $context
     * @param MeoWallet       $meoWallet
     * @param MeoWalletLogger $logger
     */
    public function __construct(Context $context, MeoWallet $meoWallet, MeoWalletLogger $logger = null)
    {

        parent::__construct($context);
        $this->context = $context;
        $this->meoWallet = $meoWallet;
        $this->logger = $logger;
    }

    /**
     * Dispatch request
     *
     * @return \Magento\Framework\Controller\ResultInterface|ResponseInterface
     * @throws \Magento\Framework\Exception\NotFoundException
     */
    public function execute()
    {

        $code = 200;
        try {
            $operationDetails = $this->getRequestBody();
            if (!$this->meoWallet->processCallback($operationDetails)) {
                throw new \Exception;
            }
        } catch (\Exception $e) {
            $code = 400;
        }

        return $this->resultFactory->create(ResultFactory::TYPE_RAW)->setHttpResponseCode($code);

    }

    /**
     * Get the php input contents
     *
     * @return mixed
     * @throws LocalizedException
     */
    protected function getRequestBody()
    {
        $postData = file_get_contents('php://input');
        $body = json_decode($postData);
        if (!$body) {
            $this->logger->error('MeoWallet callback invalid body', ['body' => $postData]);
            throw new LocalizedException(__('MeoWallet callback invalid body'));
        }
        return $body;
    }



    /**
       * @inheritDoc
       */
      public function createCsrfValidationException(
          RequestInterface $request
      ): ?InvalidRequestException {
          /** @var Redirect $resultRedirect */
          $resultRedirect = $this->resultRedirectFactory->create();
          $resultRedirect->setPath('*/*/edit');

          return new InvalidRequestException(
              $resultRedirect,
              [new Phrase('Invalid Form Key. Please refresh the page.')]
          );
      }

      /**
       * @inheritDoc
       */
      public function validateForCsrf(RequestInterface $request): ?bool
      {
          return true;
      }
























}
