<?php
namespace PTPay\MeoWallet\Controller\Payment;

use Magento\Sales\Api\OrderManagementInterface;
use PTPay\MeoWallet\Helper\OrderManagement;
use PTPay\MeoWallet\Helper\ProCheckout;
use PTPay\MeoWallet\Logger\MeoWalletLogger;
use Magento\Framework\App\RequestInterface;

/**
 * Cancel the order. Used when a user cancels the order from meowallet gateway page
 *
 * @package PTPay\MeoWallet\Controller\Payment
 */
class Cancel extends \Magento\Framework\App\Action\Action
{
    /**
     * Customer session model
     *
     * @var \Magento\Customer\Model\Session
     */
    protected $_customerSession;
    protected $resultPageFactory;
    protected $checkoutSession;
    protected $orderRepository;
    /**
     * @var OrderManagement
     */
    private $orderManagement;
    /**
     * @var ProCheckout
     */
    private $proCheckout;
    /**
     * @var MeoWalletLogger
     */
    private $logger;

    /**
     * @param \Magento\Framework\App\Action\Context       $context
     * @param \Magento\Customer\Model\Session             $customerSession
     * @param \Magento\Sales\Api\OrderRepositoryInterface $orderRepository
     * @param \Magento\Checkout\Model\Session             $checkoutSession
     * @param OrderManagement                             $orderManagement
     * @param ProCheckout                                 $proCheckout
     * @param MeoWalletLogger                             $logger
     */
    public function __construct(
        \Magento\Framework\App\Action\Context $context,
        \Magento\Customer\Model\Session $customerSession,
        \Magento\Sales\Api\OrderRepositoryInterface $orderRepository,
        \Magento\Checkout\Model\Session $checkoutSession,
        OrderManagement $orderManagement,
        ProCheckout $proCheckout,
        MeoWalletLogger $logger
    ) {
        parent::__construct($context);
        $this->_customerSession = $customerSession;
        $this->checkoutSession = $checkoutSession;
        $this->orderRepository = $orderRepository;
        $this->orderManagement = $orderManagement;
        $this->proCheckout = $proCheckout;
        $this->logger = $logger;
    }

    /**
     * Cancel the order
     *
     * @return \Magento\Framework\Controller\Result\Redirect
     */
    public function execute()
    {
        $resultRedirect = $this->resultRedirectFactory->create();

        // get the checkout id parameter
        $checkoutId = $this->_request->getParam('checkoutid');

        $order = $this->proCheckout->getOrderByCheckoutId($checkoutId);

        if (!$order) {
            $this->logger->warning('Could not find order by checkout id', ['Checkout_Id' => $checkoutId]);
            return $resultRedirect->setPath('/');
        }

//      $this->messageManager->addError(__('Payment has been cancelled.'));
        $this->orderManagement->cancelOrder($order);


        $resultRedirect->setPath('sales/order/view/order_id/' . $order->getEntityId());


        return $resultRedirect;
    }


    /**
     * @inheritDoc
     */
    public function createCsrfValidationException(
        RequestInterface $request
    ): ?InvalidRequestException {
        /** @var Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();
        $resultRedirect->setPath('*/*/edit');

        return new InvalidRequestException(
            $resultRedirect,
            [new Phrase('Invalid Form Key. Please refresh the page.')]
        );
    }

    /**
     * @inheritDoc
     */
    public function validateForCsrf(RequestInterface $request): ?bool
    {
        return true;
    }



}