<?php
namespace PTPay\MeoWallet\Controller\Payment;

use Magento\Framework\App\Action\Action;
use Magento\Framework\App\Action\Context;
use Magento\Framework\View\Result\PageFactory;
use PTPay\MeoWallet\Logger\MeoWalletLogger;
use PTPay\MeoWallet\Model\MeoWallet;
use Magento\Framework\App\RequestInterface;
use PTPay\MeoWallet\Model\MeoWalletCheckoutFactory;


/**
 * Shows the multibanco page to the user
 *
 * @package PTPay\MeoWallet\Controller\Payment
 */
class Multibanco extends Action
{
    /**
     * @var PageFactory
     */
    private $pageFactory;
    /**
     * @var MeoWallet
     */
    private $meoWallet;
    /**
     * @var MeoWalletLogger
     */
    private $logger;

    /**
     * @param Context         $context
     * @param PageFactory     $pageFactory
     * @param MeoWallet       $meoWallet
     * @param MeoWalletLogger $logger
     */
    public function __construct(
        Context $context,
        PageFactory $pageFactory,
        MeoWallet $meoWallet,
        MeoWalletLogger $logger

    ) {
        parent::__construct($context);
        $this->pageFactory = $pageFactory;
        $this->meoWallet = $meoWallet;
        $this->logger = $logger;

    }


    /**
     * Dispatch request
     *
     * @return \Magento\Framework\Controller\ResultInterface|ResponseInterface
     * @throws \Magento\Framework\Exception\NotFoundException
     */
    public function execute()
    {
        $id = $this->_request->getParam('id');

        $mbReference = $this->meoWallet->multibanco()->getMBReferencesByOperationId($id);

        if (!$mbReference){
            $this->logger->warning('Could not find multibanco reference by operation id', ['operation_id' => $id]);
           return $this->_redirect('/');
        }

        $this->_view->loadLayout();
        $this->_view->renderLayout();
    }

    /**
     * @inheritDoc
     */
    public function createCsrfValidationException(
        RequestInterface $request
    ): ?InvalidRequestException {
        /** @var Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();
        $resultRedirect->setPath('*/*/edit');

        return new InvalidRequestException(
            $resultRedirect,
            [new Phrase('Invalid Form Key. Please refresh the page.')]
        );
    }

    /**
     * @inheritDoc
     */
    public function validateForCsrf(RequestInterface $request): ?bool
    {
        return true;
    }


}