<?php
namespace PTPay\MeoWallet\Controller\Payment;

use Magento\Customer\Model\Session;
use \Magento\Checkout\Model\Session as CheckoutSession;
use Magento\Framework\App\Action\Action;
use Magento\Framework\App\Action\Context;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\ResponseInterface;
use Magento\Quote\Api\CartManagementInterface;
use Magento\Sales\Api\OrderRepositoryInterface;
use PTPay\MeoWallet\Helper\OrderManagement;
use PTPay\MeoWallet\Logger\MeoWalletLogger;
use PTPay\MeoWallet\Model\MeoWallet;
use Magento\Framework\App\RequestInterface;

/**
 * Class Success - The user lands here after exit the meowallet gateway with success
 *
 * @package PTPay\MeoWallet\Controller\Payment
 */
class Success extends Action {
    /**
     * @var Context
     */
    private $context;
    /**
     * @var Session
     */
    private $customerSession;
    /**
     * @var MeoWallet
     */
    private $meoWallet;
    /**
     * @var CheckoutSession
     */
    private $checkoutSession;
    /**
     * @var OrderRepositoryInterface
     */
    private $orderRepository;
    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;
    /**
     * @var CartManagementInterface
     */
    private $cartManagement;
    /**
     * @var OrderManagement
     */
    private $orderManagement;
    /**
     * @var MeoWalletLogger
     */
    private $logger;

    /**
     *
     * Construct the redirect action. Inject the necessary dependencies
     *
     * @param Context                  $context
     * @param Session                  $customerSession
     * @param MeoWallet                $meoWallet
     * @param OrderManagement          $orderManagement
     * @param CheckoutSession          $checkoutSession
     * @param OrderRepositoryInterface $orderRepository
     * @param ScopeConfigInterface     $scopeConfig
     * @param CartManagementInterface  $cartManagement
     * @param MeoWalletLogger          $logger
     */
    public function __construct(
        Context $context,
        Session $customerSession,
        MeoWallet $meoWallet,
        OrderManagement $orderManagement,
        CheckoutSession $checkoutSession,
        OrderRepositoryInterface $orderRepository,
        ScopeConfigInterface $scopeConfig,
        CartManagementInterface $cartManagement,
        MeoWalletLogger $logger
    ) {
        parent::__construct($context);
        $this->context = $context;
        $this->customerSession = $customerSession;
        $this->meoWallet= $meoWallet;
        $this->checkoutSession = $checkoutSession;
        $this->orderRepository = $orderRepository;
        $this->scopeConfig = $scopeConfig;
        $this->cartManagement = $cartManagement;
        $this->orderManagement = $orderManagement;
        $this->logger = $logger;
    }

    /**
     * Dispatch request
     *
     * @return \Magento\Framework\Controller\ResultInterface|ResponseInterface
     * @throws \Magento\Framework\Exception\NotFoundException
     */
    public function execute()
    {
        $resultRedirect = $this->resultRedirectFactory->create();
        $checkoutId = $this->_request->getParam('checkoutid');

        $order = $this->meoWallet->proCheckout()->getOrderByCheckoutId($checkoutId);
        if (!$order){
            $this->logger->warning('Could not find order by checkout id', ['Checkout_Id' => $checkoutId]);
            return $resultRedirect->setPath('/');
        }

        // Everything is ok from here
        $checkoutUrl = $this->_url->getUrl('checkout/onepage/success');

        $resultRedirect->setUrl($checkoutUrl);

        return $resultRedirect;
    }

    /**
     * @inheritDoc
     */
    public function createCsrfValidationException(
        RequestInterface $request
    ): ?InvalidRequestException {
        /** @var Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();
        $resultRedirect->setPath('*/*/edit');

        return new InvalidRequestException(
            $resultRedirect,
            [new Phrase('Invalid Form Key. Please refresh the page.')]
        );
    }

    /**
     * @inheritDoc
     */
    public function validateForCsrf(RequestInterface $request): ?bool
    {
        return true;
    }

}