<?php
namespace PTPay\MeoWallet\Helper;

use Magento\Framework\App\Helper\Context;
use Magento\Framework\Encryption\EncryptorInterface;
use PTPay\MeoWallet\Logger\MeoWalletLogger;
use PTPay\MeoWallet\SDK\Api as MeoWalletApi;
use PTPay\MeoWallet\SDK\Resources\MBWAYRealtime;

/**
 * Class AbstractHelper
 *
 * @package PTPay\MeoWallet\Helper
 */
abstract class AbstractHelper extends \Magento\Framework\App\Helper\AbstractHelper
{

    /**
     * @var \PTPay\MeoWallet\SDK\Resources\MB
     */
    protected $mbApi;

    /**
     * @var \PTPay\MeoWallet\SDK\Resources\MBWAYRealtime
     */
    protected $mbWayApi;

    /**
     * @var \PTPay\MeoWallet\SDK\Resources\Checkout
     */
    protected $checkoutApi;

    /**
     * @var MeoWalletLogger
     */
    protected $_logger;

    /**
     * AbstractHelper constructor.
     *
     * @param Context            $context
     * @param EncryptorInterface $encryptor
     * @param MeoWalletLogger    $logger
     */
    public function __construct(
        Context $context,
        EncryptorInterface $encryptor,
        MeoWalletLogger $logger
    ) {
        parent::__construct($context);

        $environment = $this->scopeConfig->getValue('payment/wallet/environment',
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
        $apikey = $encryptor->decrypt($this->scopeConfig->getValue('payment/wallet/sandbox_apikey',
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE));

        $meoWalletApi = new MeoWalletApi($apikey, $environment, $logger);
        $this->mbApi = new \PTPay\MeoWallet\SDK\Resources\MB($meoWalletApi);
        $this->checkoutApi = new \PTPay\MeoWallet\SDK\Resources\Checkout($meoWalletApi);
        $this->mbWayApi    = new \PTPay\MeoWallet\SDK\Resources\MBWAYRealtime($meoWalletApi);

        // Override the parent logger
        $this->_logger = $logger;
    }

    /**
     * Retrieve configuration value
     *
     * @param string $path
     *
     * @return mixed
     */
    public function getConfigData($path)
    {
        return $this->scopeConfig->getValue($path, \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
    }

}
