<?php
namespace PTPay\MeoWallet\Helper;

use Magento\Framework\App\Helper\Context;
use Magento\Framework\Encryption\EncryptorInterface;
use Magento\Sales\Api\Data\OrderInterface;
use Magento\Catalog\Model\ResourceModel\Collection\AbstractCollection;
use Magento\Framework\Data\Collection;
use \Magento\Checkout\Model\Session as CheckoutSession;
use PTPay\MeoWallet\Logger\MeoWalletLogger;
use PTPay\MeoWallet\Model\MeoWalletMultibanco;

use PTPay\MeoWallet\SDK\Exceptions\ApiResponseException;

/**
 * Class Multibanco Handle all multibanco operations
 *
 * @package PTPay\MeoWallet\Helper
 */
class Mbway extends AbstractHelper
{

    /**
     * @var CheckoutSession
     */
    private $checkoutSession;
    /**
     * @var MeoWalletLogger
     */
    private $logger;

    /**
     * Multibanco constructor.
     *
     * @param Context                    $context
     * @param EncryptorInterface         $encryptor
     * @param MeoWalletLogger            $logger
     */
    public function __construct(
        Context $context,
        EncryptorInterface $encryptor,
        MeoWalletLogger $logger,
        CheckoutSession $session
    ) {
        $this->checkoutSession = $session;
        parent::__construct($context, $encryptor, $logger);

    }



    /**
     * Format the amount with the currency
     *
     * @param float  $amount
     * @param string $currency
     *
     * @return string
     */
    public static function formatAmount($amount, $currency)
    {
        return number_format($amount, 2) . " {$currency}";
    }



    public function createPayment(OrderInterface $order,$phone)
    {
        try {

            $client = ProCheckout::_createClient($order);
            $items = ProCheckout::_createItems($order);
            $amount = $order->getGrandTotal();
            $currency = $order->getBaseCurrencyCode();
             //DONE - item 3 - mudar o $phone pra cima dos $order pois podem vir null nas funções
            $mbway_data = $this->mbWayApi->create(
                $client,
                $items,
                $amount,
                $currency,
                $phone,
                $order->getCustomerId(),
                $order->getIncrementId(),
                $order->getCustomerEmail()
                );
            return $mbway_data;

            //return $this->saveMultibancoData($order, $mbReference);
        } catch (ApiResponseException $e) {
            $this->_logger->logApiResponseException('Multibanco could not be created on site', $e);
            return false;
        }
    }
}
