<?php
namespace PTPay\MeoWallet\Logger;

use Magento\Framework\Logger\Monolog;
use PTPay\MeoWallet\SDK\Exceptions\ApiResponseException;

/**
 * Custom logger for meowallet logs
 *
 * @package PTPay\MeoWallet\Logger
 */
class MeoWalletLogger extends Monolog
{
    const PREFIX = '[MeoWallet]';

    /**
     * @inheritDoc
     */
    public function addRecord(int $level, string $message, array $context = [], ?\Monolog\DateTimeImmutable $datetime = null): bool
    {
        $message = $this->formatMessage($message);
        return parent::addRecord($level, $message, $context, $datetime);
    }

    /**
     * Format the message to the meowallet log
     *
     * @param string $message
     *
     * @return string
     */
    protected function formatMessage($message)
    {
        return self::PREFIX . ' ' . $message;
    }

    /**
     * Log the MeoWallet Api Response Exception
     */
    public function logApiResponseException($message, ApiResponseException $e)
    {
        $message = "[API] " . $message;
        return $this->critical($message, [
            'reason' => $e->getReason(),
            'tid'    => $e->getTid(),
            'link'   => $e->getLink()
        ]);
    }
}
