<?php
namespace PTPay\MeoWallet\Model\Config;

use Magento\Checkout\Model\ConfigProviderInterface;
use Magento\Checkout\Model\Session;
use Magento\Framework\Locale\ResolverInterface;
use Magento\Customer\Helper\Session\CurrentCustomer;
use Magento\Framework\Url;
use Magento\Payment\Helper\Data as PaymentHelper;
use PTPay\MeoWallet\Model\MeoWallet;

/**
 * Class ConfigProvider
 *
 * @package PTPay\MeoWallet\Model\Config
 */
class ConfigProvider implements ConfigProviderInterface
{

    const METHOD_CODE = 'wallet';

    const PAYMENT_NAME = 'meowallet';

    /**
     * @var ResolverInterface
     */
    private $localeResolver;
    /**
     * @var CurrentCustomer
     */
    private $currentCustomer;
    /**
     * @var Session
     */
    private $checkoutSession;
    /**
     * @var PaymentHelper
     */
    private $paymentHelper;
    /**
     * @var Url
     */
    private $urlBuilder;
    /**
     * @var MeoWallet
     */
    private $meoWallet;


    public function __construct(
        MeoWallet $meoWallet,
        ResolverInterface $localeResolver,
        CurrentCustomer $currentCustomer,
        Session $checkoutSession,
        PaymentHelper $paymentHelper,
        Url $urlBuilder
    ) {
        $this->localeResolver = $localeResolver;
        $this->currentCustomer = $currentCustomer;
        $this->checkoutSession = $checkoutSession;
        $this->paymentHelper = $paymentHelper;
        $this->urlBuilder = $urlBuilder;
        $this->meoWallet = $meoWallet;
    }

    /**
     * {@inheritdoc}
     */
    public function getConfig()
    {

        $config = [
            'payment' => [
                self::PAYMENT_NAME => [
                    self::METHOD_CODE => [
                        'redirect_url'    => $this->getRedirectAction(),
                        'allowed_methods' => $this->meoWallet->getAllowedMethods()
                    ]
                ]
            ]
        ];

        return $config;
    }


    /**
     * Get the url where the user is redirected after click on place order button, on frontend
     * This data is passed to the javascript
     *
     * @see view/frontend/web/js/view/payment/method-render/wallet-method
     *
     * @return string
     */
    private function getRedirectAction()
    {
        return $this->urlBuilder->getUrl('meowallet/payment/redirect', ['_secure' => true]);
    }
}
