<?php
namespace PTPay\MeoWallet\Model\Order\Email\Sender;

use Magento\Sales\Model\Order;
use Magento\Sales\Model\Order\Email\Container\OrderCommentIdentity;
use Magento\Sales\Model\Order\Email\Container\Template;
use Magento\Sales\Model\Order\Email\NotifySender;
use Magento\Sales\Model\Order\Address\Renderer;
use Magento\Framework\Event\ManagerInterface;
use PTPay\MeoWallet\Helper\Multibanco;
use PTPay\MeoWallet\Model\MeoWalletMultibanco;
use PTPay\MeoWallet\Model\Order\Email\Container\MBReferenceIdentity;

/**
 * Email sender for multibanco references
 *
 * @package PTPay\MeoWallet\Model\Order\Email\Sender
 */
class MBReferenceSender extends NotifySender
{
    /**
     * @var Renderer
     */
    protected $addressRenderer;

    /**
     * Application Event Dispatcher
     *
     * @var ManagerInterface
     */
    protected $eventManager;

    /**
     * @param Template                         $templateContainer
     * @param OrderCommentIdentity             $identityContainer
     * @param Order\Email\SenderBuilderFactory $senderBuilderFactory
     * @param \Psr\Log\LoggerInterface         $logger
     * @param Renderer                         $addressRenderer
     * @param ManagerInterface                 $eventManager
     */
    public function __construct(
        Template $templateContainer,
        MBReferenceIdentity $identityContainer,
        \Magento\Sales\Model\Order\Email\SenderBuilderFactory $senderBuilderFactory,
        \Psr\Log\LoggerInterface $logger,
        Renderer $addressRenderer,
        ManagerInterface $eventManager
    ) {
        parent::__construct($templateContainer, $identityContainer, $senderBuilderFactory, $logger, $addressRenderer);
        $this->addressRenderer = $addressRenderer;
        $this->eventManager = $eventManager;
    }

    /**
     * Send email to customer
     *
     * @param Order  $order
     * @param bool   $notify
     * @param string $comment
     *
     * @return bool
     */
    //DONE - item 5 - mudar o $notify depois do $multibanco pois o multi é required e o notidy nao
    public function send(Order $order, MeoWalletMultibanco $multibanco, $notify = true)
    {
        $transport = [
            'rnd'                      => $order->getIncrementId() . '/' . $multibanco->getData('reference'),
            'order'                    => $order,
            'entity'                   => $multibanco->getData('entity'),
            'reference'                => Multibanco::formatReference($multibanco->getData('reference')),
            'amount'                   => Multibanco::formatAmount($multibanco->getData('amount'),
                $multibanco->getData('currency')),
            'expires'                  => Multibanco::formatExpireDate($multibanco->getData('expires_at')),
            'billing'                  => $order->getBillingAddress(),
            'store'                    => $order->getStore(),
            'formattedShippingAddress' => $this->getFormattedShippingAddress($order),
            'formattedBillingAddress'  => $this->getFormattedBillingAddress($order),
        ];

        $this->eventManager->dispatch(
            'email_order_comment_set_template_vars_before',
            ['sender' => $this, 'transport' => $transport]
        );

        $this->templateContainer->setTemplateVars($transport);

        try {
            return $this->checkAndSend($order, $notify);
        } catch (\Exception $e){
            $this->logger->error($e->getMessage());
            return false;
        }
    }
}