<?php

namespace PTPay\MeoWallet\SDK;


class ApiResponse
{

    protected $metadata;
    protected $data;

    /**
     * ApiResponse constructor.
     * @param array $metadata
     * @param array $data
     */
    public function __construct($metadata = [], $data = null)
    {
        $this->metadata = $metadata;
        $this->data = $data;
    }

    /**
     * Get the response http code
     * @return int
     */
    public function getHttpCode()
    {
        $httpCode = $this->getMetadataInfo('http_code');
        return ($httpCode != null) ? (int)$httpCode : null;
    }

    /**
     * The response is a success
     * @return bool
     */
    public function isSuccess()
    {
        return $this->getHttpCode() == 200;
    }

    /**
     * Get the data as an array
     * @return array
     */
    public function getDataAsArray()
    {
        return json_decode($this->data, true);
    }

    /**
     * Get data from the metadata array
     * @param string $key
     * @return mixed|null
     */
    protected function getMetadataInfo($key)
    {
        if (isset($this->metadata[$key])) {
            return $this->metadata[$key];
        }
        return null;
    }


}