<?php
namespace PTPay\MeoWallet\SDK;
/**
 * Class Encryption
 */
final class Encryption {
    /**
     * @var string
     */
	private $key;
    /**
     * @var string
     */
	private $cipher;
    /**
     * @var int
     */
	private $iv_len;
    /**
     * @var string
     */
	private $iv;

	const IV_SEPARATOR = '::';


    /**
     * Encryption constructor.
     * @param $key
     * @param string $cipher | if not supported use the first one supported
     */
	public function __construct($key,$cipher = "aes-256-cbc") {

		$this->key = hash('sha256', $key, true);
		$methods =  openssl_get_cipher_methods();
		if (!in_array($cipher,$methods)){
				error_log("Cant use $cipher, using ".$methods[0]);
				$cipher = $methods[0];
		}
		$this->cipher = $cipher;



		$this->iv_len = openssl_cipher_iv_length($cipher);
        $this->iv     = openssl_random_pseudo_bytes($this->iv_len);

	}

    /**
     * Encrypt a given string and verify it
     * @param $data
     * @return string
     * @throws \Exception
     */
    function encrypt($data) {
        $iv = openssl_random_pseudo_bytes(openssl_cipher_iv_length($this->cipher));
        $encrypted = openssl_encrypt($data, $this->cipher, $this->key, 0, $iv);
        $enc_data =  base64_encode($encrypted . static::IV_SEPARATOR . $iv);

        $this->verifyEncryptedData($data, $enc_data);
        return $enc_data;
    }

    /**
     * @param $data
     * @return false|string
     */
    function decrypt($data) {

        list($encrypted_data, $iv) = explode(static::IV_SEPARATOR, base64_decode($data), 2);
        return openssl_decrypt($encrypted_data, $this->cipher, $this->key, 0, $iv);
    }

    /**
     * @param $data | plain data
     * @param $enc_data | | encrypted data
     * @throws \Exception
     */
    protected function verifyEncryptedData($data, $enc_data)
    {
        if ($this->decrypt($enc_data) !== $data) {
            throw new \Exception("Cant use openssl to secure store values");
        }
    }


}
