<?php
/**
 * Created by PhpStorm.
 * User: jmp
 * Date: 21-07-2016
 * Time: 16:59
 */

namespace PTPay\MeoWallet\SDK\Resources;
use Magento\Framework\App\Config\ScopeConfigInterface;

class MB extends ApiResource 
{

    /**
     * Default expiration days for new references
     */
    private $defaultMbExpirationDays = 2;

    /**
     * MB constructor.
     * @param \PTPay\MeoWallet\SDK\Api $api
     */
    public function __construct($api)
    {
        parent::__construct($api);

        $config = \Magento\Framework\App\ObjectManager::getInstance()->get(ScopeConfigInterface::class);
        
        // Recupere o valor da configuração
        $mbExpirationDays = $config->getValue('payment/wallet/mb_expiration_days', \Magento\Store\Model\ScopeInterface::SCOPE_STORE);
        $this->defaultMbExpirationDays = $mbExpirationDays !== null ? $mbExpirationDays : $this->defaultMbExpirationDays;
        
    }

    /**
     * Create MB reference data
     * @param float $amount
     * @param string $extInvoiceId
     * @param string $currency
     * @param string $expires
     * @return array
     * @throws \PTPay\MeoWallet\SDK\Exceptions\ApiResponseException
     */
    public function createReference($amount, $extInvoiceId, $currency = 'EUR', \DateTime $expires = null)
    {

        if (!$expires) {
            $expiresDate = new \DateTime();
            $expires = $expiresDate->modify("+" . $this->defaultMbExpirationDays . " day");
        }
        $expires = $expires->format('c');

        $requestData = [
            'amount'        => strval(round($amount,2)),
            'ext_invoiceid' => strval($extInvoiceId),
            'currency'      => strval($currency),
            'expires'       => strval($expires)
        ];

        $response = $this->api->call('POST', '/mb/pay', $requestData);

        return $response->getDataAsArray();
    }

} 
?>