<?php

namespace PTPay\MeoWallet\SDK\Resources;


class MBWAYRealtime extends ApiResource
{
    const MBWAY_RELATIME = 'MBWAY';
    const MBWAY_OP_TYPE  = 'PAYMENT';

    /**
     * Default expiration seconds for new references
     */
    const DEFAULT_EXPIRE_TIME_SECONDS = 600;

    /**
     * MB constructor.
     * @param  \PTPay\MeoWallet\SDK\Api  $api
     */
    public function __construct($api)
    {
        parent::__construct($api);
    }

    public function formatMbWayPhone($phone)
    {
        return $phone;
    }

    //DONE - item 3 - mudar o $mbway_phone pra cima dos nulls
    public function create(
        $client,
        $items,
        $amount,
        $currency,
        $mbway_phone,
        $extCustomerId = null,
        $extInvoiceId = null,
        $extEmail = null
    ) {
        $requestClient = [
            'name' => $client->getName(),
            'email' => $client->getEmail(),
            'address' => [
                'country' => $client->getAddress()->getCountry(),
                'address' => $client->getAddress()->getAddress(),
                'city' => $client->getAddress()->getCity(),
                'postalcode' => $client->getAddress()->getPostalcode(),
            ]
        ];
        $requestPayment = [
            'method' => static::MBWAY_RELATIME,
            'type'   => static::MBWAY_OP_TYPE,
            'mbway'  => [
                'phone' => $this->formatMbWayPhone($mbway_phone)
            ],
            'amount'   => round($amount,2),
            'client'   => $requestClient,
            'currency' => $currency,
        ];
        if ($extInvoiceId) {
            $requestPayment['ext_invoiceid'] = $extInvoiceId;
        }
        if ($extCustomerId) {
            $requestPayment['ext_customerid'] = $extCustomerId;
        }
        if ($extEmail) {
            $requestPayment['ext_email'] = $extEmail;
        }
        $requestItems = [];
        foreach ($items as $item) {
            /** @var \PTPay\MeoWallet\SDK\Structures\Item $item */
            $requestItems[] = [
                'ref'   => $item->getRef(),
                'name'  => $item->getName(),
                'descr' => $item->getDescription(),
                'qt' => $item->getQuantity(),
            ];
        }
        $requestPayment['items'] = $requestItems;
        $response = $this->api->call('POST', '/payment', $requestPayment);

        return $response->getDataAsArray();
    }

    /**
     * @param $operation_id
     * @return Operations;
     */
    public function get($operation_id)
    {
        /** @var \PTPay\MeoWallet\SDK\Resources\Operations $operations */
        $operations = new Operations($this->api);
        return $operations->getOperation($operation_id);
    }

}
