<?php

namespace PTPay\MeoWallet\SDK\Resources;


class Operations extends ApiResource
{

    /**
     * Operations constructor.
     * @param \PTPay\MeoWallet\SDK\Api $api
     */
    public function __construct($api)
    {
        parent::__construct($api);
    }

    /**
     * Get the wallet operations
     * @param null $startDate Iso 8601 start date
     * @param null $endDate Iso 8601 end date
     * @param null $limit Results limit
     * @param null $offset Results offset
     * @param null $extInvoiceId The external invoice id
     * @return array
     */
    public function getOperations(
        $startDate = null,
        $endDate = null,
        $limit = null,
        $offset = null,
        $extInvoiceId = null
    ) {
        $queryParams = [
            'start-date'     => $startDate,
            'end-date'       => $endDate,
            'limit'          => $limit,
            'offset'         => $offset,
            'ext_invoice_id' => $extInvoiceId
        ];

        // Remove unused parameters from query params
        $queryParams = array_filter($queryParams, function ($item) {
            return $item != null;
        });

        // Prepare for http get query params. turns ['key']=>'value' into ['key']=>'key=value'
        array_walk($queryParams, function (&$paramValue, $paramKey) {
            $paramValue = $paramKey . '=' . $paramValue;
        });

        // Turns the params array into param1=value1&param2=value2&param3=value3
        $queryParamsString = implode('&', $queryParams);
        $resource = '/operations/?' . $queryParamsString;

        return $this->api->call('GET', $resource)->getDataAsArray();
    }

    /**
     * @param string $operationId
     * @return array
     */
    public function getOperation($operationId)
    {
        return ($this->api->call('GET', "/operations/{$operationId}")->getDataAsArray());
    }
}